Crate sounding_analysis [−] [src]
Functions and data types for analyzing soundings from the sounding-base crate.
Reexports
pub use error::*; |
pub use layers::Layer; |
pub use parcel::Parcel; |
Modules
| error |
Error types for the sounding-analysis crate. |
| layers |
This module finds significant layers such as the dendritic snow growth zone, the hail growth zone, and inversions. |
| levels |
This module finds significant levels such as the freezing level and wet bulb zero level. It also
has functions for finding critical values at a single level, such as the maximum wet bulb
temperature aloft. It does not include functions for finding levels related to parcel analysis
and convection, those are found in the |
| parcel |
Functions for doing parcel analysis on a sounding, specifically related to convection. |
| profile |
Calculate profiles, if possible, given a sounding. |
Functions
| linear_interpolate |
Interpolate values from the vertical sounding using pressure as the primary coordinate. |