Enum sounding_analysis::error::AnalysisError[][src]

pub enum AnalysisError {
    MissingProfile,
    MissingValue,
    NotEnoughData,
    NoDataProfile,
    InvalidInput,
}

Error type for the crate.

Variants

A profile that is required for this analysis is missing.

A value (surface value, index, location, etc) that is required is not available.

Not enough data available for anlaysis

There is no data available that meets the requirements.

Bad or invalid input.

Methods

impl AnalysisError
[src]