Enum sounding_analysis::error::AnalysisError [−][src]
pub enum AnalysisError {
MissingProfile,
MissingValue,
NotEnoughData,
NoDataProfile,
InvalidInput,
}Error type for the crate.
Variants
MissingProfileA profile that is required for this analysis is missing.
MissingValueA value (surface value, index, location, etc) that is required is not available.
NotEnoughDataNot enough data available for anlaysis
NoDataProfileThere is no data available that meets the requirements.
InvalidInputBad or invalid input.
Methods
impl AnalysisError[src]
impl AnalysisErrorTrait Implementations
impl Clone for AnalysisError[src]
impl Clone for AnalysisErrorfn clone(&self) -> AnalysisError[src]
fn clone(&self) -> AnalysisErrorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Copy for AnalysisError[src]
impl Copy for AnalysisErrorimpl PartialEq for AnalysisError[src]
impl PartialEq for AnalysisErrorfn eq(&self, other: &AnalysisError) -> bool[src]
fn eq(&self, other: &AnalysisError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for AnalysisError[src]
impl Eq for AnalysisErrorimpl Debug for AnalysisError[src]
impl Debug for AnalysisErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Fail for AnalysisError[src]
impl Fail for AnalysisErrorfn cause(&self) -> Option<&Fail>[src]
fn cause(&self) -> Option<&Fail>Returns a reference to the underlying cause of this failure, if it is an error that wraps other errors. Read more
fn backtrace(&self) -> Option<&Backtrace>[src]
fn backtrace(&self) -> Option<&Backtrace>Returns a reference to the Backtrace carried by this failure, if it carries one. Read more
fn context<D>(self, context: D) -> Context<D> where
D: Display + Send + Sync + 'static, [src]
fn context<D>(self, context: D) -> Context<D> where
D: Display + Send + Sync + 'static, Provides context for this failure. Read more
fn compat(self) -> Compat<Self>[src]
fn compat(self) -> Compat<Self>Wraps this failure in a compatibility wrapper that implements std::error::Error. Read more
fn causes(&self) -> Causes[src]
fn causes(&self) -> CausesReturns a iterator over the causes of this Fail with itself as the first item and the root_cause as the final item. Read more
fn root_cause(&self) -> &(Fail + 'static)[src]
fn root_cause(&self) -> &(Fail + 'static)Returns the "root cause" of this Fail - the last value in the cause chain which does not return an underlying cause. Read more
impl Display for AnalysisError[src]
impl Display for AnalysisErrorAuto Trait Implementations
impl Send for AnalysisError
impl Send for AnalysisErrorimpl Sync for AnalysisError
impl Sync for AnalysisError